@@ -39,6 +39,7 @@ ncombinations <- function(x = NULL, k = n, n = NULL, v = NULL, freq = NULL, repl
 #' @param skip the number of combinations skipped
 #' @param index a vector of indices of the desired combinations
 #' @param nsample sampling random combinations
+#' @param drop vectorize a matrix or unlist a list
 #' @seealso [icombinations] for iterating combinations and [ncombinations] to calculate number of combinations
 #' @examples
 #' # choose 2 from 4
@@ -74,9 +75,9 @@ ncombinations <- function(x = NULL, k = n, n = NULL, v = NULL, freq = NULL, repl
 #'
 #' @export
 combinations <- function(x = NULL, k = n, n = NULL, v = NULL, freq = NULL, replace = FALSE,
-                         layout = "row", nitem = -1L, skip = NULL, index = NULL, nsample = NULL) {
+                         layout = NULL, nitem = -1L, skip = NULL, index = NULL, nsample = NULL, drop = NULL) {
     .Call("get_combinations", PACKAGE = "arrangements",
-          x, k, n, v, freq, replace, layout, nitem, index, nsample, NULL, skip, FALSE)
+          x, k, n, v, freq, replace, layout, nitem, index, nsample, NULL, skip, drop)
 }
 
 
@@ -111,53 +112,22 @@ Combinations <- R6::R6Class(
         },
         reset = function() {
             private$state <- new.env()
-            private$null_pending <- FALSE
+            private$state$null_pending <- FALSE
         },
         collect = function(layout = "row") {
             out <- self$getnext(-1L, layout, drop = FALSE)
             self$reset()
             out
         },
-        getnext = function(d = 1L, layout = NULL, drop = d == 1L && is.null(layout)) {
-            if (private$null_pending) {
+        getnext = function(d = 1L, layout = NULL, drop = NULL) {
+            if (private$state$null_pending) {
                 out <- NULL
                 self$reset()
             } else {
                 out <- .Call("get_combinations", PACKAGE = "arrangements",
                              NULL, self$k, self$n, self$v, self$freq, self$replace, layout,
-                             d, NULL, NULL, private$state, 0L, drop)
-
-                if (layout == "row" || is.null(layout)){
-                    if (nrow(out) == 0) {
-                        out <- NULL
-                        self$reset()
-                    } else if (nrow(out) < d || ncol(out) == 0) {
-                        private$null_pending <- TRUE
-                    }
-                    if (!is.null(out) && drop) {
-                        dim(out) <- NULL
-                    }
-                } else if (layout == "column"){
-                    if (ncol(out) == 0) {
-                        out <- NULL
-                        self$reset()
-                    } else if (ncol(out) < d || nrow(out) == 0) {
-                        private$null_pending <- TRUE
-                    }
-                    if (!is.null(out) && drop) {
-                        dim(out) <- NULL
-                    }
-                } else if (layout == "list"){
-                    if (length(out) == 0) {
-                        out <- NULL
-                        self$reset()
-                    } else if (length(out) < d) {
-                        private$null_pending <- TRUE
-                    }
-                    if (length(out) > 1 && drop) {
-                        out <- unlist(out)
-                    }
-                }
+                             d, NULL, NULL, private$state, NULL, drop)
+                is.null(out) && self$reset()
             }
             out
         },
