@@ -62,9 +62,9 @@ npartitions <- function(n, k = NULL, bigz = FALSE) {
 #' dim(partitions(0, 1))
 #'
 #' @export
-partitions <- function(n, k = NULL, descending = FALSE, layout = "row") {
+partitions <- function(n, k = NULL, descending = FALSE, layout = NULL) {
     .Call("get_partitions", PACKAGE = "arrangements",
-          n, k, descending, layout, -1, NULL, NULL, NULL, NULL)
+          n, k, descending, layout, -1, NULL, NULL, NULL, NULL, FALSE)
 }
 
 
@@ -97,53 +97,22 @@ Partitions <- R6::R6Class(
         },
         reset = function() {
             private$state <- new.env()
-            private$null_pending <- FALSE
+            private$state$null_pending <- FALSE
         },
         collect = function(layout = "row") {
             out <- self$getnext(-1L, layout, drop = FALSE)
             self$reset()
             out
         },
-        getnext = function(d = 1L, layout = NULL, drop = d == 1L && is.null(layout)) {
-            if (private$null_pending) {
+        getnext = function(d = 1L, layout = NULL, drop = NULL) {
+            if (private$state$null_pending) {
                 out <- NULL
                 self$reset()
             } else {
                 out <- .Call("get_partitions", PACKAGE = "arrangements",
                              self$n, self$k, self$descending, layout, d, NULL, NULL,
-                             private$state, NULL)
-
-                if (layout == "row" || is.null(layout)){
-                    if (nrow(out) == 0) {
-                        out <- NULL
-                        self$reset()
-                    } else if (nrow(out) < d || ncol(out) == 0) {
-                        private$null_pending <- TRUE
-                    }
-                    if (!is.null(out) && drop) {
-                        dim(out) <- NULL
-                    }
-                } else if (layout == "column"){
-                    if (ncol(out) == 0) {
-                        out <- NULL
-                        self$reset()
-                    } else if (ncol(out) < d || nrow(out) == 0) {
-                        private$null_pending <- TRUE
-                    }
-                    if (!is.null(out) && drop) {
-                        dim(out) <- NULL
-                    }
-                } else if (layout == "list"){
-                    if (length(out) == 0) {
-                        out <- list()
-                        self$reset()
-                    } else if (length(out) < d) {
-                        private$null_pending <- TRUE
-                    }
-                    if (length(out) > 0 && drop) {
-                        out <- unlist(out)
-                    }
-                }
+                             private$state, NULL, drop)
+                is.null(out) && self$reset()
             }
             out
         },
