@@ -132,5 +132,31 @@ SEXP get_combinations(SEXP _x, SEXP _k, SEXP _n, SEXP _v, SEXP _freq, SEXP _repl
         }
     }
 
+    attach_factor_levels(ans, _v);
+    if ((!Rf_isNull(_drop) && Rf_asLogical(_drop)) ||
+                (d == 1 && Rf_isNull(_layout)) ||
+                (!Rf_isNull(_index) && index_length(_index) == 1 && Rf_isNull(_layout)) ||
+                (!Rf_isNull(_nsample) && as_uint(_nsample) == 1 && Rf_isNull(_layout))) {
+        if (layout == 'r' && Rf_nrows(ans) == 1) {
+            Rf_setAttrib(ans, R_DimSymbol, R_NilValue);
+        } else if (layout == 'c' && Rf_ncols(ans) == 1) {
+            Rf_setAttrib(ans, R_DimSymbol, R_NilValue);
+        } else if (layout == 'l' && Rf_length(ans) == 1) {
+            ans = VECTOR_ELT(ans, 0);
+        }
+    }
+
+    if (d > 0 && !Rf_isNull(state)) {
+        if ((layout == 'r' && (Rf_nrows(ans) == 0)) ||
+                        (layout == 'c' && Rf_ncols(ans) == 0) ||
+                        (layout == 'l' && Rf_length(ans) == 0)) {
+                    ans = R_NilValue;
+        } else if ((layout == 'r' && (Rf_nrows(ans) < d)) ||
+                (layout == 'c' && Rf_ncols(ans) < d) ||
+                (layout == 'l' && Rf_length(ans) < d)) {
+            Rf_defineVar(Rf_install("null_pending"), Rf_ScalarLogical(1), state);
+        }
+    }
+
     return ans;
 }
