@@ -197,7 +197,7 @@ SEXP next_multiset_combinations(int* fp, size_t flen, int k, SEXP labels, char l
     unsigned int* mp;
     unsigned int* ap;
 
-    if (!variable_exist(state, "m", INTSXP, n, (void**) &mp)) {
+    if (!variable_exists(state, "m", INTSXP, n, (void**) &mp)) {
         h = 0;
         for (i = 0; i < flen; i++) {
             for (j = 0; j < fp[i]; j++) {
@@ -207,7 +207,7 @@ SEXP next_multiset_combinations(int* fp, size_t flen, int k, SEXP labels, char l
         status = 0;
     }
 
-    if (!variable_exist(state, "a", INTSXP, n, (void**) &ap)) {
+    if (!variable_exists(state, "a", INTSXP, n, (void**) &ap)) {
         if (Rf_isNull(_skip)) {
             for (i = 0; i < n; i++) {
                 ap[i] = mp[i];
