@@ -38,7 +38,7 @@ SEXP npartitions(SEXP _n, SEXP _k, SEXP _bigz) {
 
 
 SEXP get_partitions(SEXP _n, SEXP _k, SEXP _descending, SEXP _layout, SEXP _d,
-                    SEXP _index, SEXP _nsample, SEXP state, SEXP _skip) {
+                    SEXP _index, SEXP _nsample, SEXP state, SEXP _skip, SEXP _drop) {
 
     SEXP ans = R_NilValue;
 
@@ -91,5 +91,31 @@ SEXP get_partitions(SEXP _n, SEXP _k, SEXP _descending, SEXP _layout, SEXP _d,
             ans = next_asc_k_partitions(n, k, layout, d, state);
         }
     }
+
+    if ((!Rf_isNull(_drop) && Rf_asLogical(_drop)) ||
+                (d == 1 && Rf_isNull(_layout)) ||
+                (!Rf_isNull(_index) && index_length(_index) == 1 && Rf_isNull(_layout)) ||
+                (!Rf_isNull(_nsample) && as_uint(_nsample) == 1 && Rf_isNull(_layout))) {
+        if (layout == 'r' && Rf_nrows(ans) == 1) {
+            Rf_setAttrib(ans, R_DimSymbol, R_NilValue);
+        } else if (layout == 'c' && Rf_ncols(ans) == 1) {
+            Rf_setAttrib(ans, R_DimSymbol, R_NilValue);
+        } else if (layout == 'l' && Rf_length(ans) == 1) {
+            ans = VECTOR_ELT(ans, 0);
+        }
+    }
+
+    if (d > 0 && !Rf_isNull(state)) {
+        if ((layout == 'r' && (Rf_nrows(ans) == 0)) ||
+                        (layout == 'c' && Rf_ncols(ans) == 0) ||
+                        (layout == 'l' && Rf_length(ans) == 0)) {
+                    ans = R_NilValue;
+        } else if ((layout == 'r' && (Rf_nrows(ans) < d)) ||
+                (layout == 'c' && Rf_ncols(ans) < d) ||
+                (layout == 'l' && Rf_length(ans) < d)) {
+            Rf_defineVar(Rf_install("null_pending"), Rf_ScalarLogical(1), state);
+        }
+    }
+
     return ans;
 }
