@@ -83,7 +83,7 @@ SEXP next_replacement_permutations(int n, int k, SEXP labels, char layout, int d
 
     unsigned int* ap;
 
-    if (!variable_exist(state, "a", INTSXP, k, (void**) &ap)) {
+    if (!variable_exists(state, "a", INTSXP, k, (void**) &ap)) {
         if (Rf_isNull(_skip)) {
             for(i=0; i<k; i++) ap[i] = 0;
         } else {
